@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -21,7 +21,7 @@
 #include <QColorDialog>
 #include <QIcon>
 #include <QPointer>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QTextBlock>
 #include <QTextDocumentFragment>
 #include <QTextList>
@@ -32,10 +32,10 @@ using namespace std::chrono_literals;
 
 using namespace KPIMTextEdit;
 
-class Q_DECL_HIDDEN RichTextComposerControler::RichTextComposerControlerPrivate
+class Q_DECL_HIDDEN RichTextComposerControler::RichTextComposerControllerPrivate
 {
 public:
-    RichTextComposerControlerPrivate(RichTextComposer *composer, RichTextComposerControler *qq)
+    RichTextComposerControllerPrivate(RichTextComposer *composer, RichTextComposerControler *qq)
         : richtextComposer(composer)
         , q(qq)
     {
@@ -43,17 +43,23 @@ public:
         richTextImages = new RichTextComposerImages(richtextComposer, q);
     }
 
-    ~RichTextComposerControlerPrivate()
+    ~RichTextComposerControllerPrivate()
     {
         delete nestedListHelper;
     }
 
+    void regenerateColorScheme()
+    {
+        mLinkColor = KColorScheme(QPalette::Active, KColorScheme::View).foreground(KColorScheme::LinkText).color();
+        // TODO update existing link
+    }
+
     QColor linkColor()
     {
         if (mLinkColor.isValid()) {
             return mLinkColor;
         }
-        mLinkColor = KColorScheme(QPalette::Active, KColorScheme::View).foreground(KColorScheme::LinkText).color();
+        regenerateColorScheme();
         return mLinkColor;
     }
 
@@ -72,7 +78,7 @@ public:
     bool painterActive = false;
 };
 
-void RichTextComposerControler::RichTextComposerControlerPrivate::selectLinkText(QTextCursor *cursor) const
+void RichTextComposerControler::RichTextComposerControllerPrivate::selectLinkText(QTextCursor *cursor) const
 {
     // If the cursor is on a link, select the text of the link.
     if (cursor->charFormat().isAnchor()) {
@@ -114,7 +120,7 @@ void RichTextComposerControler::RichTextComposerControlerPrivate::selectLinkText
     }
 }
 
-void RichTextComposerControler::RichTextComposerControlerPrivate::mergeFormatOnWordOrSelection(const QTextCharFormat &format)
+void RichTextComposerControler::RichTextComposerControllerPrivate::mergeFormatOnWordOrSelection(const QTextCharFormat &format)
 {
     QTextCursor cursor = richtextComposer->textCursor();
     QTextCursor wordStart(cursor);
@@ -134,12 +140,20 @@ void RichTextComposerControler::RichTextComposerControlerPrivate::mergeFormatOnW
 
 RichTextComposerControler::RichTextComposerControler(RichTextComposer *richtextComposer, QObject *parent)
     : QObject(parent)
-    , d(new RichTextComposerControlerPrivate(richtextComposer, this))
+    , d(new RichTextComposerControllerPrivate(richtextComposer, this))
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    connect(qApp, &QApplication::paletteChanged, this, &RichTextComposerControler::regenerateColorScheme);
+#endif
 }
 
 RichTextComposerControler::~RichTextComposerControler() = default;
 
+void RichTextComposerControler::regenerateColorScheme()
+{
+    d->regenerateColorScheme();
+}
+
 bool RichTextComposerControler::painterActive() const
 {
     return d->painterActive;
@@ -328,7 +342,11 @@ void RichTextComposerControler::setTextBackgroundColor(const QColor &color)
 void RichTextComposerControler::setFontFamily(const QString &fontFamily)
 {
     QTextCharFormat fmt;
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
     fmt.setFontFamily(fontFamily);
+#else
+    fmt.setFontFamilies(QStringList() << fontFamily);
+#endif
     d->mergeFormatOnWordOrSelection(fmt);
     richTextComposer()->setFocus();
     richTextComposer()->activateRichText();
@@ -479,7 +497,7 @@ void RichTextComposerControler::updateLink(const QString &linkUrl, const QString
     d->updateLink(linkUrl, linkText);
 }
 
-void RichTextComposerControler::RichTextComposerControlerPrivate::updateLink(const QString &linkUrl, const QString &linkText)
+void RichTextComposerControler::RichTextComposerControllerPrivate::updateLink(const QString &linkUrl, const QString &linkText)
 {
     q->selectLinkText();
 
@@ -541,7 +559,7 @@ QString RichTextComposerControler::toCleanHtml() const
 
     // Qt inserts various style properties based on the current mode of the editor (underline,
     // bold, etc), but only empty paragraphs *also* have qt-paragraph-type set to 'empty'.
-    static const QString EMPTYLINEREGEX = QStringLiteral("<p style=\"-qt-paragraph-type:empty;(.*)</p>");
+    static const QRegularExpression EMPTYLINEREGEX(QStringLiteral("<p style=\"-qt-paragraph-type:empty;(.*?)</p>"));
 
     static const QString OLLISTPATTERNQT = QStringLiteral("<ol style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px;");
 
@@ -556,19 +574,8 @@ QString RichTextComposerControler::toCleanHtml() const
     // Although we can simply remove the margin-top style property, we still get unwanted results
     // if you have three or more empty lines. It's best to replace empty <p> elements with <p>&nbsp;</p>.
 
-    QRegExp emptyLineFinder(EMPTYLINEREGEX);
-    emptyLineFinder.setMinimal(true);
-
-    // find the first occurrence
-    int offset = emptyLineFinder.indexIn(result, 0);
-    while (offset != -1) {
-        // replace all the matching text with the new line text
-        result.replace(offset, emptyLineFinder.matchedLength(), EMPTYLINEHTML);
-        // advance the search offset to just beyond the last replace
-        offset += EMPTYLINEHTML.length();
-        // find the next occurrence
-        offset = emptyLineFinder.indexIn(result, offset);
-    }
+    // replace all the matching text with the new line text
+    result.replace(EMPTYLINEREGEX, EMPTYLINEHTML);
 
     // fix 2a - ordered lists - MS Outlook treats margin-left:0px; as
     // a non-existing number; e.g: "1. First item" turns into "First Item"
@@ -666,7 +673,7 @@ void RichTextComposerControler::ensureCursorVisible()
     QTimer::singleShot(500ms, richTextComposer()->composerControler(), &RichTextComposerControler::ensureCursorVisibleDelayed);
 }
 
-void RichTextComposerControler::RichTextComposerControlerPrivate::fixupTextEditString(QString &text) const
+void RichTextComposerControler::RichTextComposerControllerPrivate::fixupTextEditString(QString &text) const
 {
     // Remove line separators. Normal \n chars are still there, so no linebreaks get lost here
     text.remove(QChar::LineSeparator);
@@ -862,7 +869,7 @@ void RichTextComposerControler::addQuotes(const QString &defaultQuote)
     cursor.endEditBlock();
 }
 
-QString RichTextComposerControler::RichTextComposerControlerPrivate::addQuotesToText(const QString &inputText, const QString &defaultQuoteSign)
+QString RichTextComposerControler::RichTextComposerControllerPrivate::addQuotesToText(const QString &inputText, const QString &defaultQuoteSign)
 {
     QString answer = inputText;
     answer.replace(QLatin1Char('\n'), QLatin1Char('\n') + defaultQuoteSign);
@@ -937,3 +944,14 @@ QString RichTextComposerControler::toWrappedPlainText(QTextDocument *doc) const
     d->fixupTextEditString(temp);
     return temp;
 }
+
+bool RichTextComposerControler::event(QEvent *ev)
+{
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    if (ev->type() == QEvent::ApplicationPaletteChange) {
+        regenerateColorScheme();
+    }
+#endif
+
+    return QObject::event(ev);
+}
