@@ -38,7 +38,7 @@ MarkupDirector::~MarkupDirector()
     delete d_ptr;
 }
 
-//#define ADD_HEADER_SUPPORT 1
+// #define ADD_HEADER_SUPPORT 1
 
 QTextFrame::iterator MarkupDirector::processBlockContents(QTextFrame::iterator frameIt, const QTextBlock &block)
 {
@@ -612,7 +612,12 @@ void MarkupDirector::processOpeningElements(const QTextBlock::iterator &it)
             m_builder->beginFontPointSize(d->m_openFontPointSize);
             break;
         case SpanFontFamily:
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
             d->m_openFontFamily = fragmentFormat.fontFamily();
+#else
+            d->m_openFontFamily =
+                fragmentFormat.fontFamilies().toStringList().isEmpty() ? QString() : fragmentFormat.fontFamilies().toStringList().constFirst();
+#endif
             m_builder->beginFontFamily(d->m_openFontFamily);
             break;
         case SpanBackground:
@@ -681,7 +686,6 @@ QSet<int> MarkupDirector::getElementsToClose(const QTextBlock::iterator &it) con
     }
 
     const auto fragmentFormat = fragment.charFormat();
-
     const auto fontWeight = fragmentFormat.fontWeight();
     const auto fontItalic = fragmentFormat.fontItalic();
     const auto fontUnderline = fragmentFormat.fontUnderline();
@@ -689,8 +693,12 @@ QSet<int> MarkupDirector::getElementsToClose(const QTextBlock::iterator &it) con
 
     const auto fontForeground = fragmentFormat.foreground();
     const auto fontBackground = fragmentFormat.background();
-
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+    const QStringList families = fragmentFormat.fontFamilies().toStringList();
+    const auto fontFamily = families.isEmpty() ? QString() : families.constFirst();
+#else
     const auto fontFamily = fragmentFormat.fontFamily();
+#endif
     const auto fontPointSize = fragmentFormat.font().pointSize();
     const auto anchorHref = fragmentFormat.anchorHref();
 
@@ -765,7 +773,12 @@ QList<int> MarkupDirector::getElementsToOpen(const QTextBlock::iterator &it)
     const auto fontForeground = fragmentFormat.foreground();
     const auto fontBackground = fragmentFormat.background();
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+    const QStringList families = fragmentFormat.fontFamilies().toStringList();
+    const auto fontFamily = families.isEmpty() ? QString() : families.constFirst();
+#else
     const auto fontFamily = fragmentFormat.fontFamily();
+#endif
     const auto fontPointSize = fragmentFormat.font().pointSize();
     const auto anchorHref = fragmentFormat.anchorHref();
 
